/// <reference types="node" />
import { EthExecutionAPI, SignedTransactionInfoAPI, Address, BlockNumberOrTag, Bytes, Filter, Numbers, TransactionReceipt, Transaction, TransactionCall, TransactionWithLocalWalletIndex, Web3EthExecutionAPI } from 'web3-types';
import { Web3Context, Web3PromiEvent } from 'web3-core';
import { FormatType, DataFormat } from 'web3-utils';
import { SendSignedTransactionEvents, SendSignedTransactionOptions, SendTransactionEvents, SendTransactionOptions } from './types';
export declare const getProtocolVersion: (web3Context: Web3Context<EthExecutionAPI>) => Promise<string>;
export declare const isSyncing: (web3Context: Web3Context<EthExecutionAPI>) => Promise<import("web3-types").SyncingStatusAPI>;
export declare const getCoinbase: (web3Context: Web3Context<EthExecutionAPI>) => Promise<string>;
export declare const isMining: (web3Context: Web3Context<EthExecutionAPI>) => Promise<boolean>;
export declare function getHashRate<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getGasPrice<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getBlockNumber<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getBalance<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, address: Address, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getStorageAt<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, address: Address, storageSlot: Numbers, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<string>;
export declare function getCode<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, address: Address, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<string>;
export declare function getBlock<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, block: string | number | bigint | Uint8Array | ArrayBuffer | Buffer | undefined, hydrated: boolean | undefined, returnFormat: ReturnFormat): Promise<{
    readonly parentHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly sha3Uncles: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly miner: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly stateRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly transactionsRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly receiptsRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly logsBloom?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly difficulty?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly number: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly gasLimit: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly gasUsed: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly timestamp: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly extraData: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly mixHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly nonce: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly totalDifficulty: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly baseFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly size: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly transactions: string[] | {
        readonly blockHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        readonly blockNumber?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        readonly from: string;
        readonly hash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
        readonly transactionIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        value?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        accessList?: {
            readonly address?: string | undefined;
            readonly storageKeys?: string[] | undefined;
        }[] | undefined;
        common?: {
            customChain: {
                name?: string | undefined;
                networkId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
                chainId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
            };
            baseChain?: import("web3-types").ValidChains | undefined;
            hardfork?: import("web3-types").Hardfork | undefined;
        } | undefined;
        to?: string | null | undefined;
        gas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        gasPrice?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        type?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        maxFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        maxPriorityFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        input?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        nonce?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        chain?: import("web3-types").ValidChains | undefined;
        hardfork?: import("web3-types").Hardfork | undefined;
        chainId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        networkId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        gasLimit?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        yParity?: string | undefined;
        v?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        r?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        s?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    }[];
    readonly uncles: string[];
    readonly hash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
}>;
export declare function getBlockTransactionCount<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, block: string | number | bigint | Uint8Array | ArrayBuffer | Buffer | undefined, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getBlockUncleCount<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, block: string | number | bigint | Uint8Array | ArrayBuffer | Buffer | undefined, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getUncle<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, block: string | number | bigint | Uint8Array | ArrayBuffer | Buffer | undefined, uncleIndex: Numbers, returnFormat: ReturnFormat): Promise<{
    readonly parentHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly sha3Uncles: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly miner: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly stateRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly transactionsRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly receiptsRoot: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly logsBloom?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly difficulty?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly number: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly gasLimit: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly gasUsed: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly timestamp: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly extraData: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly mixHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly nonce: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly totalDifficulty: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly baseFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly size: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly transactions: string[] | {
        readonly blockHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        readonly blockNumber?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        readonly from: string;
        readonly hash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
        readonly transactionIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        value?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        accessList?: {
            readonly address?: string | undefined;
            readonly storageKeys?: string[] | undefined;
        }[] | undefined;
        common?: {
            customChain: {
                name?: string | undefined;
                networkId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
                chainId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
            };
            baseChain?: import("web3-types").ValidChains | undefined;
            hardfork?: import("web3-types").Hardfork | undefined;
        } | undefined;
        to?: string | null | undefined;
        gas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        gasPrice?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        type?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        maxFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        maxPriorityFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        input?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        nonce?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        chain?: import("web3-types").ValidChains | undefined;
        hardfork?: import("web3-types").Hardfork | undefined;
        chainId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        networkId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        gasLimit?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        yParity?: string | undefined;
        v?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
        r?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
        s?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    }[];
    readonly uncles: string[];
    readonly hash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
}>;
export declare function getTransaction<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, transactionHash: Bytes, returnFormat: ReturnFormat): Promise<{
    readonly blockHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly blockNumber?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly from: string;
    readonly hash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly transactionIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    value?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    accessList?: {
        readonly address?: string | undefined;
        readonly storageKeys?: string[] | undefined;
    }[] | undefined;
    common?: {
        customChain: {
            name?: string | undefined;
            networkId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
            chainId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
        };
        baseChain?: import("web3-types").ValidChains | undefined;
        hardfork?: import("web3-types").Hardfork | undefined;
    } | undefined;
    to?: string | null | undefined;
    gas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasPrice?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    type?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxPriorityFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    input?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    nonce?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    chain?: import("web3-types").ValidChains | undefined;
    hardfork?: import("web3-types").Hardfork | undefined;
    chainId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    networkId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasLimit?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    yParity?: string | undefined;
    v?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    r?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    s?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
} | undefined>;
export declare function getPendingTransactions<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, returnFormat: ReturnFormat): Promise<{
    from?: string | undefined;
    value?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    accessList?: {
        readonly address?: string | undefined;
        readonly storageKeys?: string[] | undefined;
    }[] | undefined;
    common?: {
        customChain: {
            name?: string | undefined;
            networkId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
            chainId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
        };
        baseChain?: import("web3-types").ValidChains | undefined;
        hardfork?: import("web3-types").Hardfork | undefined;
    } | undefined;
    to?: string | null | undefined;
    gas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasPrice?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    type?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxPriorityFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    input?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    nonce?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    chain?: import("web3-types").ValidChains | undefined;
    hardfork?: import("web3-types").Hardfork | undefined;
    chainId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    networkId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasLimit?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    yParity?: string | undefined;
    v?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    r?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    s?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
}[]>;
export declare function getTransactionFromBlock<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, block: string | number | bigint | Uint8Array | ArrayBuffer | Buffer | undefined, transactionIndex: Numbers, returnFormat: ReturnFormat): Promise<{
    readonly blockHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly blockNumber?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly from: string;
    readonly hash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly transactionIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    value?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    accessList?: {
        readonly address?: string | undefined;
        readonly storageKeys?: string[] | undefined;
    }[] | undefined;
    common?: {
        customChain: {
            name?: string | undefined;
            networkId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
            chainId: import("web3-utils").NumberTypes[ReturnFormat["number"]];
        };
        baseChain?: import("web3-types").ValidChains | undefined;
        hardfork?: import("web3-types").Hardfork | undefined;
    } | undefined;
    to?: string | null | undefined;
    gas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasPrice?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    type?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    maxPriorityFeePerGas?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    input?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    nonce?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    chain?: import("web3-types").ValidChains | undefined;
    hardfork?: import("web3-types").Hardfork | undefined;
    chainId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    networkId?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    gasLimit?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    yParity?: string | undefined;
    v?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    r?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    s?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
} | undefined>;
export declare function getTransactionReceipt<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, transactionHash: Bytes, returnFormat: ReturnFormat): Promise<TransactionReceipt | undefined>;
export declare function getTransactionCount<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, address: Address, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function sendTransaction<ReturnFormat extends DataFormat, ResolveType = FormatType<TransactionReceipt, ReturnFormat>>(web3Context: Web3Context<EthExecutionAPI>, transaction: Transaction | TransactionWithLocalWalletIndex, returnFormat: ReturnFormat, options?: SendTransactionOptions<ResolveType>): Web3PromiEvent<ResolveType, SendTransactionEvents<ReturnFormat>>;
export declare function sendSignedTransaction<ReturnFormat extends DataFormat, ResolveType = FormatType<TransactionReceipt, ReturnFormat>>(web3Context: Web3Context<EthExecutionAPI>, signedTransaction: Bytes, returnFormat: ReturnFormat, options?: SendSignedTransactionOptions<ResolveType>): Web3PromiEvent<ResolveType, SendSignedTransactionEvents<ReturnFormat>>;
export declare function sign<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, message: Bytes, addressOrIndex: Address | number, returnFormat: ReturnFormat): Promise<string | {
    readonly messageHash: string;
    readonly r: string;
    readonly s: string;
    readonly v: string;
    readonly message?: string | undefined;
    readonly signature: string;
}>;
export declare function signTransaction<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, transaction: Transaction, returnFormat: ReturnFormat): Promise<SignedTransactionInfoAPI>;
export declare function call<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, transaction: TransactionCall, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<string>;
export declare function estimateGas<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, transaction: Transaction, blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getLogs<ReturnFormat extends DataFormat>(web3Context: Web3Context<Web3EthExecutionAPI>, filter: Filter, returnFormat: ReturnFormat): Promise<(string | {
    readonly removed?: boolean | undefined;
    readonly logIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly transactionIndex?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly transactionHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly blockHash?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly blockNumber?: import("web3-utils").NumberTypes[ReturnFormat["number"]] | undefined;
    readonly address?: string | undefined;
    readonly data?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]] | undefined;
    readonly topics?: import("web3-utils").ByteTypes[ReturnFormat["bytes"]][] | undefined;
    readonly id?: string | undefined;
})[]>;
export declare function getChainId<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, returnFormat: ReturnFormat): Promise<import("web3-utils").NumberTypes[ReturnFormat["number"]]>;
export declare function getProof<ReturnFormat extends DataFormat>(web3Context: Web3Context<Web3EthExecutionAPI>, address: Address, storageKeys: Bytes[], blockNumber: BlockNumberOrTag | undefined, returnFormat: ReturnFormat): Promise<{
    readonly balance: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly codeHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly nonce: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly storageHash: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
    readonly accountProof: import("web3-utils").ByteTypes[ReturnFormat["bytes"]][];
    readonly storageProof: {
        readonly key: import("web3-utils").ByteTypes[ReturnFormat["bytes"]];
        readonly value: import("web3-utils").NumberTypes[ReturnFormat["number"]];
        readonly proof: import("web3-utils").ByteTypes[ReturnFormat["bytes"]][];
    }[];
}>;
export declare function getFeeHistory<ReturnFormat extends DataFormat>(web3Context: Web3Context<EthExecutionAPI>, blockCount: Numbers, newestBlock: BlockNumberOrTag | undefined, rewardPercentiles: Numbers[], returnFormat: ReturnFormat): Promise<{
    readonly oldestBlock: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly baseFeePerGas: import("web3-utils").NumberTypes[ReturnFormat["number"]];
    readonly reward: import("web3-utils").NumberTypes[ReturnFormat["number"]][][];
    readonly gasUsedRatio: import("web3-utils").NumberTypes[ReturnFormat["number"]];
}>;
//# sourceMappingURL=rpc_method_wrappers.d.ts.map