import { TransactionError } from 'web3-errors';
import { Bytes, Numbers, Transaction, TransactionReceipt } from 'web3-types';
import { DataFormat, ETH_DATA_FORMAT, FormatType } from 'web3-utils';
export declare type InternalTransaction = FormatType<Transaction, typeof ETH_DATA_FORMAT>;
export declare type SendTransactionEvents<ReturnFormat extends DataFormat> = {
    sending: FormatType<Transaction, typeof ETH_DATA_FORMAT>;
    sent: FormatType<Transaction, typeof ETH_DATA_FORMAT>;
    transactionHash: FormatType<Bytes, ReturnFormat>;
    receipt: FormatType<TransactionReceipt, ReturnFormat>;
    confirmation: {
        confirmations: FormatType<Numbers, ReturnFormat>;
        receipt: FormatType<TransactionReceipt, ReturnFormat>;
        latestBlockHash: FormatType<Bytes, ReturnFormat>;
    };
    error: TransactionError<FormatType<TransactionReceipt, ReturnFormat>>;
};
export declare type SendSignedTransactionEvents<ReturnFormat extends DataFormat> = {
    sending: FormatType<Bytes, typeof ETH_DATA_FORMAT>;
    sent: FormatType<Bytes, typeof ETH_DATA_FORMAT>;
    transactionHash: FormatType<Bytes, ReturnFormat>;
    receipt: FormatType<TransactionReceipt, ReturnFormat>;
    confirmation: {
        confirmations: FormatType<Numbers, ReturnFormat>;
        receipt: FormatType<TransactionReceipt, ReturnFormat>;
        latestBlockHash: FormatType<Bytes, ReturnFormat>;
    };
    error: TransactionError<FormatType<TransactionReceipt, ReturnFormat>>;
};
export interface SendTransactionOptions<ResolveType = TransactionReceipt> {
    ignoreGasPricing?: boolean;
    transactionResolver?: (receipt: TransactionReceipt) => ResolveType;
}
export interface SendSignedTransactionOptions<ResolveType = TransactionReceipt> {
    transactionResolver?: (receipt: TransactionReceipt) => ResolveType;
}
//# sourceMappingURL=types.d.ts.map