"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncingSubscription = exports.NewHeadsSubscription = exports.NewPendingTransactionsSubscription = exports.LogsSubscription = void 0;
const web3_utils_1 = require("web3-utils");
const web3_core_1 = require("web3-core");
const schemas_1 = require("./schemas");
class LogsSubscription extends web3_core_1.Web3Subscription {
    _buildSubscriptionParams() {
        return ['logs', this.args];
    }
    _processSubscriptionResult(data) {
        this.emit('data', (0, web3_utils_1.format)(schemas_1.logSchema, data, super.returnFormat));
    }
    _processSubscriptionError(error) {
        this.emit('error', error);
    }
}
exports.LogsSubscription = LogsSubscription;
class NewPendingTransactionsSubscription extends web3_core_1.Web3Subscription {
    _buildSubscriptionParams() {
        return ['newPendingTransactions'];
    }
    _processSubscriptionResult(data) {
        this.emit('data', (0, web3_utils_1.format)({ eth: 'string' }, data, super.returnFormat));
    }
    _processSubscriptionError(error) {
        this.emit('error', error);
    }
}
exports.NewPendingTransactionsSubscription = NewPendingTransactionsSubscription;
class NewHeadsSubscription extends web3_core_1.Web3Subscription {
    _buildSubscriptionParams() {
        return ['newHeads'];
    }
    _processSubscriptionResult(data) {
        this.emit('data', (0, web3_utils_1.format)(schemas_1.blockHeaderSchema, data, super.returnFormat));
    }
    _processSubscriptionError(error) {
        this.emit('error', error);
    }
}
exports.NewHeadsSubscription = NewHeadsSubscription;
class SyncingSubscription extends web3_core_1.Web3Subscription {
    _buildSubscriptionParams() {
        return ['syncing'];
    }
    _processSubscriptionResult(data) {
        if (typeof data === 'boolean') {
            this.emit('changed', data);
        }
        else {
            const mappedData = Object.fromEntries(Object.entries(data.status).map(([key, value]) => [
                key.charAt(0).toLowerCase() + key.substring(1),
                value,
            ]));
            this.emit('changed', data.syncing);
            this.emit('data', (0, web3_utils_1.format)(schemas_1.syncSchema, mappedData, super.returnFormat));
        }
    }
    _processSubscriptionError(error) {
        this.emit('error', error);
    }
}
exports.SyncingSubscription = SyncingSubscription;
//# sourceMappingURL=web3_subscriptions.js.map